@@ -188,16 +188,18 @@ class Spider(object):
                     response.encoding = "utf-8"
                     if count < info.request_retry_times:
                         logging.info("Got data at times %d from url %s" % (count, info.request_url))
-                    return index, response.status_code
+                    return index, int(response.status_code)
                 except Exception as exp:
                     logging.warning(
                         "Failed to request url at times=%d [%s] wait for %f seconds" % (
-                            count, exp, count
+                            count, exp, info.request_retry_delay_seconds
                         )
                     )
                     count = count - 1
                     time.sleep(info.request_retry_delay_seconds)
 
+            raise ConnectionError("Failed to request url %s" % info.request_url)
+
     async def phase_request_get(self, info: Message) -> str:
         """
         HTTP GET请求
@@ -279,7 +281,7 @@ class Spider(object):
             except Exception as exp:
                 logging.warning(
                     "Failed to request url at times=%d [%s] wait for %f seconds" % (
-                        count, exp, count
+                        count, exp, message.request_retry_delay_seconds
                     )
                 )
                 time.sleep(message.request_retry_delay_seconds)
@@ -311,7 +313,7 @@ class Spider(object):
             except Exception as exp:
                 logging.warning(
                     "Failed to parse at times=%d [%s] wait for %f seconds" % (
-                        count, exp, count
+                        count, exp, message.parse_retry_delay_seconds
                     )
                 )
                 time.sleep(message.parse_retry_delay_seconds)
